QueryResponse

Struct QueryResponse 

pub struct QueryResponse {
    pub kind: String,
    pub etag: Option<String>,
    pub schema: Option<TableSchema>,
    pub job_reference: JobReference,
    pub total_rows: Option<String>,
    pub page_token: Option<String>,
    pub rows: Vec<Value>,
    pub total_bytes_processed: Option<String>,
    pub job_complete: bool,
    pub errors: Option<Vec<ErrorProto>>,
    pub cache_hit: bool,
    pub num_dml_affected_rows: Option<String>,
}

Fields

kind: Stringetag: Option<String>schema: Option<TableSchema>job_reference: JobReferencetotal_rows: Option<String>

dry runs do not have total rows

page_token: Option<String>rows: Vec<Value>total_bytes_processed: Option<String>job_complete: boolerrors: Option<Vec<ErrorProto>>cache_hit: boolnum_dml_affected_rows: Option<String>

Implementations

Source

impl QueryResponse

pub fn retry(self, client: &Client) -> Self

pub fn into_csv(self) -> String

pub fn into_json(self) -> Value

this needs works it is not outputting proper json format it needs to convert from google bigqquery protobuf